/****************************************************************
Copyright (c) 1998 Sandro Sigala <ssigala@globalnet.it>.
All rights reserved.

Permission to use, copy, modify, and distribute this software
and its documentation for any purpose and without fee is hereby
granted, provided that the above copyright notice appear in all
copies and that both that the copyright notice and this
permission notice and warranty disclaimer appear in supporting
documentation, and that the name of the author not be used in
advertising or publicity pertaining to distribution of the
software without specific, written prior permission.

The author disclaim all warranties with regard to this
software, including all implied warranties of merchantability
and fitness.  In no event shall the author be liable for any
special, indirect or consequential damages or any damages
whatsoever resulting from loss of use, data or profits, whether
in an action of contract, negligence or other tortious action,
arising out of or in connection with the use or performance of
this software.
****************************************************************/

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <ktopwidget.h>
#include <qlist.h>

#include "map.h"

class KMenuBar;
class QPopupMenu;
class MainWidget;
class SpriteWindow;
class MapWindow;

class MainWindow : public KTopLevelWidget {
	Q_OBJECT

public:
	MainWindow(const char *name = 0);
	~MainWindow();

	void loadEpisode(const QString& path);
	void loadSprites(const QString& path);
	void selectLevel(int level);

private:
	KMenuBar *menu;
	QPopupMenu *file_popup, *options_popup;
	QPopupMenu *windows_popup, *help_popup;
	int strictID, alignID;
	bool strict_checking, auto_align;
	MainWidget *view;
	QList<Map> maps;
	SpriteWindow *sprite_window;
	MapWindow *map_window;
	QPixmap *sprites;
	QString episode_path;

	void updateMapsList();
	void updateTransportersList(int level);
	bool strictCheckTransporter(Map *map, const QString& thismap, int x, int y);
	bool strictCheckTransporters(Map *map, const QString& thismap);
	bool strictCheck();
	void showWindows();
	void alignWindows();

public slots:
	void menu_strictCheck();
	void menu_save();
	void menu_strictChecking();
	void menu_alignWindows();
        void menu_spriteEditor();
        void menu_levelEditor();
	void menu_realign();
        void menu_help();
        void menu_about();
	void menu_aboutKDE();

	void mapInsert();
	void mapRemove();
	void mapMoveUp();
	void mapMoveDown();
	void transporterInsert();
	void transporterRemove();
	void selectedMap(int level);
	void changedPassword(const char *s);
	void changedTime(const char *s);
	void changedSprite();

protected:
	void moveEvent(QMoveEvent *e);
};

#endif // !MAINWINDOW_H
